@@ -309,6 +309,13 @@ impl Error {
             fn status(&self) -> StatusCode {
                 self.0
             }
+
+            fn as_response(&self) -> Response
+            where
+                Self: StdError + Send + Sync + 'static,
+            {
+                self.0.into_response()
+            }
         }
 
         StatusError(status).into()
